@@ -216,7 +216,9 @@ buffer.  It constructs a shell command:
 sed \"1i <prompt>: \" <file> | <ai-code-cli>
 and runs it in a compilation buffer."
   (interactive)
-  (when (eq ai-code-selected-backend 'agent-shell)
+  (when (eq (and (boundp 'ai-code-selected-backend)
+                 ai-code-selected-backend)
+            'agent-shell)
     (user-error "Backend 'agent-shell' does not support piping file content via ai-code-cli"))
   (let* ((prompt (ai-code-read-string "Prompt: "))
          (suffix-parts (delq nil (list ai-code-prompt-suffix
