@@ -13,7 +13,7 @@
 
 (declare-function ai-code--git-root "ai-code-file" (&optional dir))
 
-(defvar ai-code-use-gptel-headline)
+(defvar ai-code-use-gptel-headline nil)
 (defvar ai-code-prompt-suffix)
 (defvar ai-code-auto-test-type)
 (defvar ai-code-auto-test-suffix)
@@ -150,6 +150,15 @@ Only works when gptel package is installed, otherwise shows error message."
   "Get the buffer for PROMPT-FILE, without selecting it."
   (find-file-noselect prompt-file))
 
+(defun ai-code--insert-backend-label-drawer ()
+  "Insert an Org drawer recording the current AI backend label."
+  (let ((label (condition-case nil
+                   (ai-code-current-backend-label)
+                 (error "unknown"))))
+    (insert ":PROPERTIES:\n")
+    (insert (format ":AGENT: %s\n" label))
+    (insert ":END:\n")))
+
 (defun ai-code--append-prompt-to-buffer (prompt-text)
   "Append formatted PROMPT-TEXT to the end of the current buffer.
 This includes generating a headline and formatting the prompt.
@@ -157,6 +166,7 @@ Returns the full prompt text with suffix for sending to AI."
   (goto-char (point-max))
   (insert "\n\n")
   (ai-code--generate-prompt-headline prompt-text)
+  (ai-code--insert-backend-label-drawer)
   (ai-code--format-and-insert-prompt prompt-text))
 
 (defun ai-code--send-prompt (full-prompt)
@@ -202,15 +212,15 @@ If WORD is a file path, it's converted to a relative path."
 
 (defun ai-code--preprocess-prompt-text (prompt-text)
   "Preprocess PROMPT-TEXT to replace file paths with relative paths.
-The function splits the prompt by whitespace, checks if each part is a file
-path within the current git repository, and if so, replaces it with a
-relative path prefixed with @.
+The function checks each non-whitespace token in the prompt; if a token is a
+file path within the current git repository it is replaced with a relative
+path prefixed with @.  Original whitespace is preserved.
 NOTE: This does not handle file paths containing spaces."
   (if-let* ((git-root-truename (ai-code--git-root)))
-      (mapconcat
+      (replace-regexp-in-string
+       "[^ \t\n]+"
        (lambda (word) (ai-code--process-word-for-filepath word git-root-truename))
-       (split-string prompt-text "[ \t\n]+" t) ; split by whitespace and remove empty strings
-       " ")
+       prompt-text t t)
     ;; Not in a git repo, return original prompt
     prompt-text))
 
@@ -500,6 +510,9 @@ Returns a filename with .org suffix."
   (insert (format "#+DATE: %s\n" (format-time-string "%Y-%m-%d")))
   (unless (string-empty-p task-url)
     (insert (format "#+URL: %s\n" task-url)))
+  (let ((branch (magit-get-current-branch)))
+    (when branch
+      (insert (format "#+BRANCH: %s\n" branch))))
   (let ((label (ai-code-current-backend-label)))
     (insert (format "#+AGENT: %s\n" label))
     (insert "#+SESSION_ID: <Usually you can get the session id with /status or /stat in AI coding window>\n"))
@@ -568,12 +581,7 @@ using GPTel, and creates the task file."
 
 ;;;###autoload
 (add-to-list 'auto-mode-alist
-             `(,(concat "^"
-                        (regexp-quote
-                         (file-name-as-directory
-                          (expand-file-name ai-code-files-dir-name)))
-                        ".*\\.org\\'")
-               . ai-code-prompt-mode))
+             '("/\\.ai\\.code\\.files/.*\\.org\\'" . ai-code-prompt-mode))
 
 (provide 'ai-code-prompt-mode)
 
