@@ -1,8 +1,8 @@
-;;; ai-code.el --- Unified interface for AI coding backends such as Claude Code, Codex CLI, Gemini CLI, Copilot CLI, Opencode, Grok CLI, Aider CLI, agent-shell, etc -*- lexical-binding: t; -*-
+;;; ai-code.el --- Unified interface for AI coding backends such as Claude Code, Codex CLI, Gemini CLI, Copilot CLI, Opencode, Grok CLI, Aider CLI, etc -*- lexical-binding: t; -*-
 
 ;; Author: Kang Tu <tninja@gmail.com>
-;; Package-Version: 20260219.2126
-;; Package-Revision: b8d7aef928f1
+;; Package-Version: 20260224.346
+;; Package-Revision: 882c3b55bb5e
 ;; Package-Requires: ((emacs "28.1") (transient "0.8.0") (magit "2.1.0"))
 ;; URL: https://github.com/tninja/ai-code-interface.el
 
@@ -29,6 +29,20 @@
 ;;   - Aider CLI
 ;;   - agent-shell
 ;;
+;; New User Quick Start:
+;;   1) Minimal setup:
+;;
+;;      (use-package ai-code
+;;        :config
+;;        (ai-code-set-backend 'codex)
+;;        (global-set-key (kbd "C-c a") #'ai-code-menu))
+;;
+;;   2) First 60 seconds:
+;;      - C-c a a : Start AI CLI session
+;;      - C-c a c : Ask AI to change current function/region
+;;      - C-c a q : Ask question only (no code change)
+;;      - C-c a z : Jump back to active AI session buffer
+;;
 ;; Basic configuration example:
 ;;
 ;; (use-package ai-code
@@ -103,6 +117,7 @@
 (declare-function ai-code-backends-infra--session-buffer-p "ai-code-backends-infra" (buffer))
 
 (declare-function ai-code--process-word-for-filepath "ai-code-prompt-mode" (word git-root-truename))
+(declare-function ai-code-call-gptel-sync "ai-code-prompt-mode" (question))
 
 ;; Default aliases are set when a backend is applied via `ai-code-select-backend`.
 
@@ -164,12 +179,61 @@ with a newline separator."
         (cdr choice-cell)
       'test-after-change)))
 
-(defun ai-code--resolve-auto-test-type-for-send ()
-  "Resolve the concrete auto test type for the current send action."
+;;;###autoload
+(defcustom ai-code-use-gptel-classify-prompt nil
+  "Whether to use GPTel to classify prompts in `ask-me` auto test mode.
+When non-nil and `ai-code-auto-test-type` is not nil, classify whether
+the current prompt is about code changes. If not, skip test type selection
+and do not append auto test suffix."
+  :type 'boolean
+  :group 'ai-code)
+
+(defun ai-code--gptel-classify-prompt-code-change (prompt-text)
+  "Classify whether PROMPT-TEXT requests code changes using GPTel.
+Return one of: `code-change`, `non-code-change`, or `unknown`."
+  (let ((classification
+         (condition-case err
+             (if (require 'gptel nil t)
+                 (let* ((raw-answer (ai-code-call-gptel-sync
+                                     (concat "Classify whether this user prompt requests code changes in a repository.\n"
+                                             "Reply with exactly one token: CODE_CHANGE or NOT_CODE_CHANGE.\n"
+                                             "Treat edit/refactor/implement/fix/add/remove/update/tests as CODE_CHANGE.\n"
+                                             "Treat explain/summarize/discuss/review without editing as NOT_CODE_CHANGE.\n\n"
+                                             "Prompt:\n" prompt-text)))
+                        (answer (upcase (string-trim (or raw-answer "")))))
+                   (cond
+                    ((string-match-p "\\`CODE_CHANGE\\b" answer) 'code-change)
+                    ((string-match-p "\\`NOT_CODE_CHANGE\\b" answer) 'non-code-change)
+                    (t 'unknown)))
+               'unknown)
+           (error
+            (message "GPTel prompt classification failed: %s" (error-message-string err))
+            'unknown))))
+    (message "GPTel prompt classification result: %s" classification)
+    classification))
+
+(defun ai-code--resolve-auto-test-type-for-send (&optional prompt-text)
+  "Resolve the concrete auto test type for current send action for PROMPT-TEXT."
   (pcase ai-code-auto-test-type
-    ('ask-me (ai-code--read-auto-test-type-choice))
-    ('test-after-change 'test-after-change)
-    ('tdd 'tdd)
+    ('ask-me
+     (if ai-code-use-gptel-classify-prompt
+         (pcase (ai-code--gptel-classify-prompt-code-change prompt-text)
+           ('code-change (ai-code--read-auto-test-type-choice))
+           ('non-code-change nil)
+           (_ (ai-code--read-auto-test-type-choice)))
+       (ai-code--read-auto-test-type-choice)))
+    ('test-after-change
+     (if ai-code-use-gptel-classify-prompt
+         (when (eq (ai-code--gptel-classify-prompt-code-change prompt-text)
+                   'code-change)
+           'test-after-change)
+       'test-after-change))
+    ('tdd
+     (if ai-code-use-gptel-classify-prompt
+         (when (eq (ai-code--gptel-classify-prompt-code-change prompt-text)
+                   'code-change)
+           'tdd)
+       'tdd))
     (_ nil)))
 
 (defun ai-code--auto-test-suffix-for-type (type)
@@ -179,14 +243,14 @@ with a newline separator."
     ('tdd (ai-code--test-after-code-change--resolve-tdd-suffix))
     (_ nil)))
 
-(defun ai-code--resolve-auto-test-suffix-for-send ()
-  "Resolve auto test suffix for the current send action."
+(defun ai-code--resolve-auto-test-suffix-for-send (&optional prompt-text)
+  "Resolve auto test suffix for current send action for PROMPT-TEXT."
   (ai-code--auto-test-suffix-for-type
-   (ai-code--resolve-auto-test-type-for-send)))
+   (ai-code--resolve-auto-test-type-for-send prompt-text)))
 
 (defun ai-code--with-auto-test-suffix-for-send (orig-fun prompt-text)
   "Resolve and bind auto test suffix before sending PROMPT-TEXT."
-  (let ((ai-code-auto-test-suffix (ai-code--resolve-auto-test-suffix-for-send)))
+  (let ((ai-code-auto-test-suffix (ai-code--resolve-auto-test-suffix-for-send prompt-text)))
     (funcall orig-fun prompt-text)))
 
 (unless (advice-member-p #'ai-code--with-auto-test-suffix-for-send
@@ -347,6 +411,7 @@ Shows the current backend label to the right."
     ("R" "Resume AI CLI (C-u: args)" ai-code-cli-resume)
     ("z" "Switch to AI CLI (C-u: hide)" ai-code-cli-switch-to-buffer-or-hide)
     ;; Use plist style to provide a dynamic description function.
+    ;; DONE: I want ai-code-select-backend (and ai-code--select-backend-description) should keep same backend for the git repo which already started ai-code-cli session, unless user explicitly want to switch in side that git repo. Eg. switch backend in git repo B should not switch backend in git repo A which already has a session, and next time user start session in repo A, it should use the same backend as before. This will be more intelligent and user friendly, and also avoid the problem that user switch backend in one repo but forget to switch back when work on another repo which already has session.
     ("s" ai-code-select-backend :description ai-code--select-backend-description)
     ("u" "Install / Upgrade AI CLI" ai-code-upgrade-backend)
     ("g" "Open backend config (eg. add mcp)" ai-code-open-backend-config)
